# Netherrack
Welcome to the Netherrack documentation. Netherrack is a tool to convert Python code into DF code templates. This project is based on [Prismarine](https://dfprismarine.github.io/), another tool to convert JavaScript code into DF. 

[Docs](https://github.com/rassoolls/netherrack-docs/blob/master/README.md)

[Discord](https://discord.gg/dXsXKXX)

# Installation
To install Netherrack, use the PyPi command:
```py
python3 -m pip install netherrack
```
And done! To use Netherrack in your project, you can import it like this:
```py
from netherrack import netherrack
```
See the documentation for more info.
